@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Help;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-08-04'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -171,6 +171,7 @@ sub gen_help {
             for my $opt (@opts) {
                 my $ospec = $opts->{$opt};
                 my $arg_spec = $ospec->{arg_spec};
+                next if grep {$_ eq 'hidden'} @{$arg_spec->{tags} // []};
                 my $is_bool = $arg_spec->{schema} &&
                     $arg_spec->{schema}[0] eq 'bool';
                 my $show_default = exists($ospec->{default}) &&
@@ -235,7 +236,7 @@ Perinci::CmdLine::Help - Generate help message for Perinci::CmdLine-based app
 
 =head1 VERSION
 
-This document describes version 0.08 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2015-09-03.
+This document describes version 0.09 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2016-08-04.
 
 =head1 DESCRIPTION
 
@@ -250,6 +251,8 @@ formatting options first though).
 
 Generate help message for Perinci::CmdLine-based app.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -285,8 +288,6 @@ Return value:  (any)
 
 =for Pod::Coverage ^()$
 
-=head1 SEE ALSO
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Help>.
@@ -303,13 +304,15 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
